@@ -1,21 +1,31 @@
-# -*- coding: utf-8 -*-
+# coding: utf-8
 #
-#  Copyright (c) 2010—2012 Andrey Mikhailenko and contributors
+#  Copyright © 2010—2014 Andrey Mikhaylenko and contributors
 #
 #  This file is part of Argh.
 #
 #  Argh is free software under terms of the GNU Lesser
 #  General Public License version 3 (LGPLv3) as published by the Free
-#  Software Foundation. See the file README for copying conditions.
+#  Software Foundation. See the file README.rst for copying conditions.
 #
 """
 Exceptions
-==========
+~~~~~~~~~~
 """
+class AssemblingError(Exception):
+    """
+    Raised if the parser could not be configured due to malformed
+    or conflicting command declarations.
+    """
+
 
 class CommandError(Exception):
-    """The only exception that is wrapped by the dispatcher. Useful for
-    print-and-exit tasks.
+    """
+    Intended to be raised from within a command.  The dispatcher wraps this
+    exception by default and prints its message without traceback.
+
+    Useful for print-and-exit tasks when you expect a failure and don't want
+    to startle the ordinary user by the cryptic output.
 
     Consider the following example::
 
