@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# coding: utf-8
 """
 Integration Tests
 ~~~~~~~~~~~~~~~~~
@@ -11,6 +11,7 @@ import mock
 import pytest
 
 import argh
+from argh.exceptions import AssemblingError
 
 from .base import DebugArghParser, run, CmdResult as R
 
@@ -201,14 +202,14 @@ def test_arg_merged():
 
 
 def test_arg_mismatch_positional():
-    """ @arg must match function signature if @command is applied.
+    """ An `@arg('positional')` must match function signature.
     """
     @argh.arg('bogus-argument')
     def confuse_a_cat(vet, funny_things=123):
         return vet, funny_things
 
     p = DebugArghParser('PROG')
-    with pytest.raises(ValueError) as excinfo:
+    with pytest.raises(AssemblingError) as excinfo:
         p.set_default_command(confuse_a_cat)
 
     msg = ("confuse_a_cat: argument bogus-argument does not fit "
@@ -217,14 +218,14 @@ def test_arg_mismatch_positional():
 
 
 def test_arg_mismatch_flag():
-    """ @arg must match function signature if @command is applied.
+    """ An `@arg('--flag')` must match function signature.
     """
     @argh.arg('--bogus-argument')
     def confuse_a_cat(vet, funny_things=123):
         return vet, funny_things
 
     p = DebugArghParser('PROG')
-    with pytest.raises(ValueError) as excinfo:
+    with pytest.raises(AssemblingError) as excinfo:
         p.set_default_command(confuse_a_cat)
 
     msg = ("confuse_a_cat: argument --bogus-argument does not fit "
@@ -232,6 +233,38 @@ def test_arg_mismatch_flag():
     assert msg in str(excinfo.value)
 
 
+def test_arg_mismatch_positional_vs_flag():
+    """ An `@arg('arg')` must match a positional arg in function signature.
+    """
+    @argh.arg('foo')
+    def func(foo=123):
+        return foo
+
+    p = DebugArghParser('PROG')
+    with pytest.raises(AssemblingError) as excinfo:
+        p.set_default_command(func)
+
+    msg = ('func: argument "foo" declared as optional (in function signature)'
+           ' and positional (via decorator)')
+    assert msg in str(excinfo.value)
+
+
+def test_arg_mismatch_flag_vs_positional():
+    """ An `@arg('--flag')` must match a keyword in function signature.
+    """
+    @argh.arg('--foo')
+    def func(foo):
+        return foo
+
+    p = DebugArghParser('PROG')
+    with pytest.raises(AssemblingError) as excinfo:
+        p.set_default_command(func)
+
+    msg = ('func: argument "foo" declared as positional (in function signature)'
+           ' and optional (via decorator)')
+    assert msg in str(excinfo.value)
+
+
 def test_backwards_compatibility_issue29():
     @argh.arg('foo')
     @argh.arg('--bar', default=1)
@@ -669,3 +702,27 @@ def test_class_members():
     assert run(p, 'class-meth foo').out == 'foo\n123\n'
     assert run(p, 'static-meth foo').out == 'foo\nw00t?\n'
     assert run(p, 'static-meth2 foo').out == 'foo\nhuh!\n'
+
+
+def test_kwonlyargs():
+    "Correct dispatch in presence of keyword-only arguments"
+    if sys.version_info < (3,0):
+        pytest.skip('unsupported configuration')
+
+    ns = {}
+
+    exec("""def cmd(*args, foo='1', bar, baz='3', **kwargs):
+                return ' '.join(args), foo, bar, baz, len(kwargs)
+         """, None, ns)
+    cmd = ns['cmd']
+
+    p = DebugArghParser()
+    p.set_default_command(cmd)
+
+    assert (run(p, '--baz=done test  this --bar=do').out ==
+            'test this\n1\ndo\ndone\n0\n')
+    if sys.version_info < (3,3):
+        message = 'argument --bar is required'
+    else:
+        message = 'the following arguments are required: --bar'
+    assert run(p, 'test --foo=do', exit=True) == message
